.. dpu_kmeans documentation master file, created by
   sphinx-quickstart on Tue Oct 12 13:23:17 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dpu_kmeans's documentation!
======================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   README.md
   dpu_kmeans

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
